cd "\\bmdgiesan\DGIESAN\PROYECTOS\DASPERI\DatosInvestigación\CursoDD\ejemplos\InstrumentosBartik"
*https://github.com/Mixtape-Sessions/Shift-Share/blob/main/Lab/Solutions/Solutions-Stata.md

/*****************************************/
/*    Example Solution for SSIV Lab      */
/* Written by Peter Hull, 5/16/2022 (v1) */
/*****************************************/

/*
This lab will walk through some basic SSIV analyses using data from Autor, Dorn, and Hanson (ADH, 2013). ADH use a shift-share instrument aggregating Chinese import shocks across 397 manufacturing instruments with exposure weights calculated as the economy-wide share of (baseline) industry employment. We will use three cleaned datasets from their setup:

adh_shocks.dta: an industry-by-year dataset of the shocks

adh_shares.dta: a location-by-industry-by-year dataset of the shares

adh_noIV.dta: 	a location-by-year dataset of the main outcome (manufacturing employment 	growth, y), treatment (local growth of China import exposure, x), and other useful variables – excluding the ADH instruments

*/


clear all

*explorar las tres bases de datos
use adh_shocks, clear
tab year 
use adh_shares, clear
use adh_noIV, clear

/*********** Construct z **********************/
/*
Construct the ADH (location-by-year) instrument by appropriately combining the data on shocks and shares. Merge this into the adh_noIV dataset, and estimate an IV regression of the outcome onto the treatment which controls for year (i.e. the post variable) and weights by baseline total employment (the weight variable), clustering by state. 
*/
use adh_shares, clear
merge m:1 industry year using adh_shocks, nogen 
gen z = ind_share * shock
collapse (sum) z, by(location year)
tempfile IV
save `IV', replace
use adh_noIV, clear
merge 1:1 location year using `IV', nogen

/* Basic SSIV regression */
ivreg2 y (x=z) post [aw=weight], cluster(state) 

/* 
Then estimate the exact same IV regression replacing the outcome y with the lagged outcome y_lag, capturing growth in manufacturing employment that took place before the ADH "China Shock" quasi-experiment. How does the latter IV regression help build support for the former IV regression? 
*/
/* Basic balance test */
ivreg2 y_lag (x=z) post [aw=weight], cluster(state) 

*Comments:
/*
The lag outcome IV estimate is much smaller than the main IV estimate (-0.131 vs -0.746) and statistically insignificant. This tells us that regions which would get a large "china shock" in the post period are not on differential outcome trends in the pre period, building support for the validity of the instrument. 
*/


/**** 2 ****/
/*
Construct the "sum-of-shares" control from the adh_shares dataset and add this control to both of the previous IV regressions. How does the main IV estimate change? Why, intuitively, is this control important to include?
*/

/* Add sum of shares control */
preserve
use adh_shares, clear
collapse (sum) sum_share=ind_share, by(location year)
tempfile sum_shares
save `sum_shares', replace
restore
merge 1:1 location year using `sum_shares', nogen
summ sum_share
/* SSIV with Sum of Shares */
ivreg2 y (x=z) post sum_share [aw=weight], cluster(state)
/* Balance test with Sum of Shares */ 
ivreg2 y_lag (x=z) post sum_share [aw=weight], cluster(state) 

*Comments:
/*
The sum-of-shares control should be included because ADH is a setting with "incomplete shares" (i.e. the sum of shares I not constant across location-years). Without this control the SSIV will be using both the variation in shocks across industries and the average "size" of the shock through the sum of shares (unless the shocks are mean-zero, which you can see they are not).
*/

/****** 3 *******/

/*
Interact the "sum-of-shares" control with year and add this control to both of the previous IV regressions. How do both IV estimates change? Can you see why, intuitively, the interaction control shifts the main IV estimate so much?
*/

/* Interact sum of shares with year */
gen post_sum_share=post*sum_share
ivreg2 y (x=z) post sum_share post_sum_share [aw=weight], cluster(state) 
ivreg2 y_lag (x=z) post sum_share post_sum_share [aw=weight], cluster(state) 

/* Check why sum of shares matters */
preserve
use adh_shocks, clear
reg shock year, cluster(industry)
restore

*Comments:
/*
Interacting the sum-of-shares control with year isolates the within-year variation in shocks. To see this take the year fixed effects as the industry-level "q_n" discussed in class and note that to leverage this control we need to control for sum_n (s_lnt*q_n) = sum_nt (s_ln)*period_t in the location-year regression. You can see that the shock mean is quite different across periods (in the post period the average shock is significantly larger) such that isolating the within-period variation makes a difference – without this control the SSIV is using both within- and across-period shock variation, and the economic conditions in the two periods are quite different (causing OVB).
*/
